<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Memoir Lite
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head itemscope itemtype="https://schema.org/WebSite">
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?> itemscope itemtype="https://schema.org/WebPage">
<?php
if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
}
?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'memoir-lite' ); ?></a>

	<header id="masthead" class="site-header" itemscope itemtype="https://schema.org/WPHeader">

		<?php get_template_part( 'template-parts/header-component' ); ?>
        <?php 
        $header_image_url = '';
        $site_header_class = '';
        if (has_header_image()) {
            $header_image_url = get_header_image();
            $site_header_class = "data-bg";
        } ?>
        <div class="site-header-area site-header-main <?php echo $site_header_class; ?>" <?php if (!empty($header_image_url)) { ?> data-background="<?php echo esc_url($header_image_url); ?>" <?php }?> >
            <div class="site-wrapper">
                <div class="site-row">

                    <div class="site-column site-column-12">
                        <div class="site-branding">
                        
                            <?php
                            if( function_exists( 'has_custom_logo' ) && has_custom_logo() ){ ?>
                            <div class="site-logo" itemscope itemtype="https://schema.org/Organization">
                                <?php the_custom_logo(); ?>
                            </div>
                            <?php }
                            
                            if ( is_front_page() && is_home() ) :
                                ?>
                                <h1 itemprop="name" class="site-title"><a itemprop="url" href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                                <?php
                            else :
                                ?>
                                <p itemprop="name" class="site-title"><a itemprop="url" href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                                <?php
                            endif;
                            $memoir_lite_description = get_bloginfo( 'description', 'display' );
                            if ( $memoir_lite_description || is_customize_preview() ) :
                                ?>
                                <p itemprop="description" class="site-description">
                                    <span><?php echo $memoir_lite_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                                </p>
                            <?php endif; ?>

                        </div><!-- .site-branding -->
                    </div>
                </div>
            </div>
		</div>

	</header><!-- #masthead -->

    <?php
    if( !is_home() && !is_front_page() && !is_archive() && !is_search() ){
        if (have_posts()) :
            /* Start the Loop */
            while (have_posts()) :
                the_post();

                memoir_lite_single_banner();

            endwhile;
        endif;

    } ?>

    <div id="content" class="site-content" role="main">
    
    <?php
    if( !is_home() && !is_front_page() && !is_404() && !is_page() && !is_single() && !is_archive() && !is_search() ){
        echo '<div class="site-wrapper">';
        memoir_lite_breadcrumb();
        echo '</div>';
    } ?>